Crate xcsoar_tasks

Crate xcsoar_tasks 

xcsoar-tasks

A Rust library for parsing and writing XCSoar task files.

Installation

Add this to your Cargo.toml:

[dependencies]
xcsoar-tasks = "0.1.0"

Usage

let xml = std::fs::read_to_string("task.tsk").unwrap();
let task = xcsoar_tasks::from_str(&xml).unwrap();

println!("Task type: {:?}", task.task_type);
for point in &task.points {
    println!("  {}: {:?}", point.waypoint.name, point.point_type);
}

License

Licensed under either of:

at your option.

Unless you explicitly state otherwise, any contribution intentionally submitted for inclusion in this crate by you, as defined in the Apache-2.0 license, shall be dually licensed as above, without any additional terms or conditions.

Structs

Location
Point
Task
Waypoint

Enums

AltitudeReference
ObservationZone
ParseError
PointType
SerializeError
TaskType

Functions

from_reader
from_str
to_string
to_string_pretty
to_writer
to_writer_pretty